@@ -185,6 +185,9 @@ INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 # 插件定义参数取值重复，请修改后重新操作。
 INVALIDPARAMETERVALUE_DUPLICATEPLUGINCONFIG = 'InvalidParameterValue.DuplicatePluginConfig'
 
+# 非法的后端ip地址。
+INVALIDPARAMETERVALUE_ILLEGALPROXYIP = 'InvalidParameterValue.IllegalProxyIp'
+
 # 密钥错误。
 INVALIDPARAMETERVALUE_INVALIDACCESSKEYIDS = 'InvalidParameterValue.InvalidAccessKeyIds'
 
@@ -272,6 +275,9 @@ INVALIDPARAMETERVALUE_INVALIDTAGVALUES = 'InvalidParameterValue.InvalidTagValues
 # TSF类型API配置错误。
 INVALIDPARAMETERVALUE_INVALIDTSFCONFIG = 'InvalidParameterValue.InvalidTsfConfig'
 
+# 当前后端通道不存在或者是无效状态。
+INVALIDPARAMETERVALUE_INVALIDUPSTREAM = 'InvalidParameterValue.InvalidUpstream'
+
 # URL参数错误。
 INVALIDPARAMETERVALUE_INVALIDURL = 'InvalidParameterValue.InvalidUrl'
 
@@ -338,6 +344,12 @@ LIMITEXCEEDED_USAGEPLANLIMITEXCEEDED = 'LimitExceeded.UsagePlanLimitExceeded'
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
+# 缺少后端服务参数。
+MISSINGPARAMETER_BACKENDSPECIFICPARAM = 'MissingParameter.BackendSpecificParam'
+
+# 插件缺少参数，请按规则重新操作。
+MISSINGPARAMETER_PLUGINCONFIG = 'MissingParameter.PluginConfig'
+
 # 操作被拒绝。
 OPERATIONDENIED = 'OperationDenied'
 
@@ -416,6 +428,9 @@ UNSUPPORTEDOPERATION_INVALIDACTION = 'UnsupportedOperation.InvalidAction'
 # 不支持后端类型。
 UNSUPPORTEDOPERATION_INVALIDENDPOINTTYPE = 'UnsupportedOperation.InvalidEndpointType'
 
+# 当前实例状态，不支持当前操作。
+UNSUPPORTEDOPERATION_INVALIDINSTANCESTATE = 'UnsupportedOperation.InvalidInstanceState'
+
 # 当前服务处于隔离中，暂不支持此操作。
 UNSUPPORTEDOPERATION_INVALIDSERVICETRADE = 'UnsupportedOperation.InvalidServiceTrade'
 
@@ -443,6 +458,9 @@ UNSUPPORTEDOPERATION_RESOURCEASSOCIATED = 'UnsupportedOperation.ResourceAssociat
 # 密钥已绑定使用计划，请先解绑再试。
 UNSUPPORTEDOPERATION_RESOURCEISINUSE = 'UnsupportedOperation.ResourceIsInUse'
 
+# 资源未关联。
+UNSUPPORTEDOPERATION_RESOURCEUNASSOCIATED = 'UnsupportedOperation.ResourceUnassociated'
+
 # 当前Uin未在手工密钥白名单列表内。
 UNSUPPORTEDOPERATION_UINNOTINWHITELIST = 'UnsupportedOperation.UinNotInWhiteList'
 
