@@ -14,6 +14,21 @@
 # limitations under the License.
 
 
+# 账号已存在于该账号组。
+FAILEDOPERATION_ACCOUNTALREADYEXISTEDINACCOUNTGROUP = 'FailedOperation.AccountAlreadyExistedInAccountGroup'
+
+# 账号组名称已存在。
+FAILEDOPERATION_ACCOUNTGROUPNAMEEXISTED = 'FailedOperation.AccountGroupNameExisted'
+
+# 账号组不存在。
+FAILEDOPERATION_ACCOUNTGROUPNOTEXISTED = 'FailedOperation.AccountGroupNotExisted'
+
+# 账号名称已存在。
+FAILEDOPERATION_ACCOUNTNAMEEXISTED = 'FailedOperation.AccountNameExisted'
+
+# 账号不存在。
+FAILEDOPERATION_ACCOUNTNOTEXISTED = 'FailedOperation.AccountNotExisted'
+
 # 加入用户到用户组异常。
 FAILEDOPERATION_ADDUSERSTOUSERGROUP = 'FailedOperation.AddUsersToUserGroup'
 
@@ -26,6 +41,9 @@ FAILEDOPERATION_APPIDNOTFOUND = 'FailedOperation.AppIdNotFound'
 # 应用不存在。
 FAILEDOPERATION_APPNOTEXISTED = 'FailedOperation.AppNotExisted'
 
+# 同一组织下不能存在相同名称的子组织机构。
+FAILEDOPERATION_CHILDORGNODENAMEEXISTS = 'FailedOperation.ChildOrgNodeNameExists'
+
 # 其子机构中存在用户的机构节点不能被删除。
 FAILEDOPERATION_CHILDORGNODEWITHUSERSCANNOTBEDELETED = 'FailedOperation.ChildOrgNodeWithUsersCannotBeDeleted'
 
@@ -50,6 +68,9 @@ FAILEDOPERATION_DELETEUSERGROUPFAILURE = 'FailedOperation.DeleteUserGroupFailure
 # 读取机构节点信息异常。
 FAILEDOPERATION_DESCRIBEORGNODEFAILURE = 'FailedOperation.DescribeOrgNodeFailure'
 
+# 读取根机构节点信息异常。
+FAILEDOPERATION_DESCRIBEORGNODEROOTFAILURE = 'FailedOperation.DescribeOrgNodeRootFailure'
+
 # EntityType取值不合法。
 FAILEDOPERATION_ENTITYTYPENOTEXISTED = 'FailedOperation.EntityTypeNotExisted'
 
@@ -59,6 +80,9 @@ FAILEDOPERATION_EXPECTFIELDSNOTFOUND = 'FailedOperation.ExpectFieldsNotFound'
 # 用户组ID未找到。
 FAILEDOPERATION_GROUPIDNOTFOUND = 'FailedOperation.GroupIdNotFound'
 
+# 数据条目超过最大限制。
+FAILEDOPERATION_ITEMSEXCEEDMAXNUMBER = 'FailedOperation.ItemsExceedMaxNumber'
+
 # 获取用户所在的用户组列表异常。
 FAILEDOPERATION_LISTUSERGROUPSOFUSERFAILURE = 'FailedOperation.ListUserGroupsOfUserFailure'
 
@@ -68,6 +92,9 @@ FAILEDOPERATION_LISTUSERSINORGNODEFAILURE = 'FailedOperation.ListUsersInOrgNodeF
 # 获取用户组中的用户列表异常。
 FAILEDOPERATION_LISTUSERSINUSERGROUPFAILURE = 'FailedOperation.ListUsersInUserGroupFailure'
 
+# 新密码必须不能为空。
+FAILEDOPERATION_NEWPASSWORDMUSTNOTBLANK = 'FailedOperation.NewPasswordMustNotBlank'
+
 # 操作失败。
 FAILEDOPERATION_OPERATIONFAILURE = 'FailedOperation.OperationFailure'
 
@@ -107,6 +134,9 @@ FAILEDOPERATION_USERALREADYEXISTEDINUSERGROUP = 'FailedOperation.UserAlreadyExis
 # 获取用户被授权访问的应用列表失败。
 FAILEDOPERATION_USERAUTHLISTFAILED = 'FailedOperation.UserAuthListFailed'
 
+# 用户邮箱已存在。
+FAILEDOPERATION_USEREMAILEXISTED = 'FailedOperation.UserEmailExisted'
+
 # 设定的时间格式不合法。
 FAILEDOPERATION_USEREXPRIATIONTIMEISILLEGAL = 'FailedOperation.UserExpriationTimeIsIllegal'
 
@@ -125,6 +155,9 @@ FAILEDOPERATION_USERNAMEEXISTED = 'FailedOperation.UserNameExisted'
 # 用户不存在于该用户组。
 FAILEDOPERATION_USERNOTEXISTEDINUSERGROUP = 'FailedOperation.UserNotExistedInUserGroup'
 
+# 用户不存在。
+FAILEDOPERATION_USERNOTFOUND = 'FailedOperation.UserNotFound'
+
 # 用户手机已存在。
 FAILEDOPERATION_USERPHONEEXISTED = 'FailedOperation.UserPhoneExisted'
 
@@ -145,3 +178,9 @@ INVALIDPARAMETER_PARAMETERLLLEGAL = 'InvalidParameter.Parameterlllegal'
 
 # 输入密码不合法。
 INVALIDPARAMETER_PASSWORDISILLEGAL = 'InvalidParameter.PasswordIsIllegal'
+
+# 用户ID参数为空。
+INVALIDPARAMETER_USERIDISNULL = 'InvalidParameter.UserIDIsNull'
+
+# 用户名参数为空。
+INVALIDPARAMETER_USERNAMEISNULL = 'InvalidParameter.UserNameIsNull'
