@@ -17,6 +17,9 @@
 # CAM签名/鉴权错误。
 AUTHFAILURE = 'AuthFailure'
 
+# 操作失败。
+FAILEDOPERATION = 'FailedOperation'
+
 # 实例安全组信息添加失败。
 FAILEDOPERATION_ADDINSTANCEINFOFAILED = 'FailedOperation.AddInstanceInfoFailed'
 
@@ -188,6 +191,9 @@ INTERNALERROR_SETSVCLOCATIONFAILED = 'InternalError.SetSvcLocationFailed'
 # 数据库更新失败。
 INTERNALERROR_UPDATEDATABASEFAILED = 'InternalError.UpdateDatabaseFailed'
 
+# 外网操作失败。
+INTERNALERROR_WANSERVICEFAILED = 'InternalError.WanServiceFailed'
+
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
@@ -197,6 +203,9 @@ INVALIDPARAMETER_ACTIONNOTFOUND = 'InvalidParameter.ActionNotFound'
 # 密码包含了非法字符。
 INVALIDPARAMETER_CHARACTERERROR = 'InvalidParameter.CharacterError'
 
+# 参数检测为通过。
+INVALIDPARAMETER_CHECKPARAMNOTPASS = 'InvalidParameter.CheckParamNotPass'
+
 # 未指定需要查询的订单ID。
 INVALIDPARAMETER_DEALNAMENOTGIVEN = 'InvalidParameter.DealNameNotGiven'
 
@@ -215,12 +224,18 @@ INVALIDPARAMETER_ILLEGALTIME = 'InvalidParameter.IllegalTime'
 # 未找到请求的实例。
 INVALIDPARAMETER_INSTANCENOTFOUND = 'InvalidParameter.InstanceNotFound'
 
+# 不支持此计费类型调用当前接口。
+INVALIDPARAMETER_NOTSUPPORTEDPAYMODE = 'InvalidParameter.NotSupportedPayMode'
+
 # 没有权限操作该接口或资源。
 INVALIDPARAMETER_PERMISSIONDENIED = 'InvalidParameter.PermissionDenied'
 
 # 安全组合法性校验不通过。
 INVALIDPARAMETER_SGCHECKFAIL = 'InvalidParameter.SGCheckFail'
 
+# 实例分片不存在。
+INVALIDPARAMETER_SHARDRESOURCEIDNOTFOUND = 'InvalidParameter.ShardResourceIdNotFound'
+
 # 找不到对应的售卖规格。
 INVALIDPARAMETER_SPECNOTFOUND = 'InvalidParameter.SpecNotFound'
 
@@ -236,6 +251,9 @@ INVALIDPARAMETER_VPCNOTFOUND = 'InvalidParameter.VpcNotFound'
 # 想要创建的账号已经存在。
 INVALIDPARAMETERVALUE_ACCOUNTALREADYEXISTS = 'InvalidParameterValue.AccountAlreadyExists'
 
+# 该实例不支持此同步模式。
+INVALIDPARAMETERVALUE_BADSYNCMODE = 'InvalidParameterValue.BadSyncMode'
+
 # 指定的权限无法赋予给该账号。
 INVALIDPARAMETERVALUE_BADUSERRIGHT = 'InvalidParameterValue.BadUserRight'
 
@@ -284,18 +302,27 @@ RESOURCEINUSE_TEMPINSTANCEEXIST = 'ResourceInUse.TempInstanceExist'
 # 指定的账号不存在。
 RESOURCENOTFOUND_ACCOUNTDOESNOTEXIST = 'ResourceNotFound.AccountDoesNotExist'
 
+# 实例不存在。
+RESOURCENOTFOUND_INSTANCENOTFOUND = 'ResourceNotFound.InstanceNotFound'
+
 # 找不到指定的数据库实例。
 RESOURCENOTFOUND_NOINSTANCEFOUND = 'ResourceNotFound.NoInstanceFound'
 
 # 接入安全组产品配置不存在。
 RESOURCENOTFOUND_PRODUCTCONFIGNOTEXISTEDERROR = 'ResourceNotFound.ProductConfigNotExistedError'
 
+# 同步任务已删除。
+RESOURCENOTFOUND_SYNCTASKDELETED = 'ResourceNotFound.SyncTaskDeleted'
+
 # 实例状态错误，不能初始化。
 RESOURCEUNAVAILABLE_BADINSTANCESTATUS = 'ResourceUnavailable.BadInstanceStatus'
 
 # COS API调用错误。
 RESOURCEUNAVAILABLE_COSAPIFAILED = 'ResourceUnavailable.CosApiFailed'
 
+# 独享集群状态不正常。
+RESOURCEUNAVAILABLE_EXCLUSTERSTATUSABNORMAL = 'ResourceUnavailable.ExclusterStatusAbnormal'
+
 # 数据库实例已被删除。
 RESOURCEUNAVAILABLE_INSTANCEALREADYDELETED = 'ResourceUnavailable.InstanceAlreadyDeleted'
 
